"use client";

import { useState, useEffect } from "react";
import { Card, CardContent } from "@/components/ui/card";
import { Button } from "@/components/ui/button";
import { Trash2, Heart } from "lucide-react";
import PageHeader from "../components/page-header";
import Image from "next/image";
import Link from "next/link";
import { AuthModal } from "../components/auth-modal";
import { useAuth } from "../context/AuthContext";
import { useCart } from "../context/CartContext";
import WishlistButton from "./WishlistButton";
export default function CartPage() {
  const [cartItems, setCartItems] = useState([]);
  const { cartCount, setCartCount } = useCart();

  const { user, logout } = useAuth();
  const [isClient, setIsClient] = useState(false);
  useEffect(() => {
    setIsClient(true);
    if (typeof window !== "undefined") {
      const storedCart = JSON.parse(localStorage.getItem("cart")) || [];
      setCartItems(storedCart);
    }
  }, []);
  const [isLoginOpen, setIsLoginOpen] = useState(false);

  const updateQuantity = (index, amount) => {
    const updatedCart = [...cartItems];
    updatedCart[index].quantity = Math.max(
      1,
      updatedCart[index].quantity + amount
    );
    setCartItems(updatedCart);
    setCartCount(updatedCart);
    localStorage.setItem("cart", JSON.stringify(updatedCart));
  };

  const removeItem = (index) => {
    const updatedCart = cartItems.filter((_, i) => i !== index);
    setCartCount(updatedCart);
    setCartItems(updatedCart);
    localStorage.setItem("cart", JSON.stringify(updatedCart));
  };

  const totalAmount = cartItems.reduce(
    (acc, item) => acc + item.quantity * parseFloat(item.price),
    0
  );

  const handleCheckout = () => {
    if (cartItems.length === 0) {
      toast.error("Cart is empty"); // Show toast if cart is empty
      return;
    }
    // If user is authenticated, navigation will happen via Link
    // If not, open login modal
    if (!user) {
      setIsLoginOpen(true);
    }
  };

  return (
    <>
      <PageHeader title="Cart" breadcrumb="Home - Cart" />

      <div className="p-6 max-w-7xl mx-auto">
        <div className="flex justify-between items-center mb-4 border-b pb-2">
          <span className="text-sm text-customGrayBlack">
            {cartItems.length} ITEM(S) IN CART
          </span>
        </div>

        <div className="grid md:grid-cols-3 gap-6">
          <div className="md:col-span-2 space-y-4">
            {cartItems.map((item, index) => (
              <Card key={index} className="flex items-center p-4 gap-4">
                <Image
                  src={item.image}
                  alt={item.product_id}
                  width={120}
                  height={120}
                  className="rounded"
                />
                <div className="flex-1">
                  <div className="flex justify-between">
                    <h3 className="font-medium">
                      {item.Color ? `Color: ${item.Color}` : ""}{" "}
                      {item.Size ? `Size: ${item.Size}` : ""}{" "}
                      {item.Weight ? `Weight: ${item.Weight}` : ""}
                    </h3>
                    <div className="flex gap-2">
                      <WishlistButton item={item} />
                      <Trash2
                        size={18}
                        className="text-red-500 cursor-pointer"
                        onClick={() => removeItem(index)}
                      />
                    </div>
                  </div>
                  <p className="font-semibold text-foreground mt-2">
                    Rs. {item.price * item.quantity || 1}
                  </p>
                  <div className="flex items-center gap-2 mt-2 justify-between">
                    <p className="text-customGrayBlack text-sm">
                      Qty: {item.quantity}
                    </p>
                    <div className="space-x-3">
                      <Button
                        variant="outline"
                        onClick={() => updateQuantity(index, -1)}
                        className="px-2 h-6"
                      >
                        -
                      </Button>
                      <span className="text-xs font-semibold">
                        {item.quantity}
                      </span>
                      <Button
                        variant="outline"
                        onClick={() => updateQuantity(index, 1)}
                        className="px-2 h-6"
                      >
                        +
                      </Button>
                    </div>
                  </div>
                </div>
              </Card>
            ))}
          </div>

          <Card className="p-4 h-fit">
            <h3 className="font-semibold mb-4">Order Summary</h3>
            <div className="space-y-3 text-sm text-customGrayBlack">
              <div className="flex justify-between">
                <span>Items Total ({cartItems.length} item)</span>
                <span>Rs. {totalAmount.toFixed(2)}</span>
              </div>
              <div className="flex justify-between">
                <span>Delivery Charges ({cartItems.length} item)</span>
                <span>Rs. {(cartItems.length * 0).toFixed(2)}</span>{" "}
                {/* Example: 50 Rs per item */}
              </div>
              <div className="flex justify-between font-semibold pt-2 border-t">
                <span>Total</span>
                <span>
                  Rs. {(totalAmount + cartItems.length * 0).toFixed(2)}
                </span>
              </div>
            </div>
            {user ? (
              <Link href={cartItems.length > 0 ? "../checkout" : "#"}>
                <Button
                  className="w-full mt-4"
                  onClick={handleCheckout}
                  disabled={cartItems.length === 0} // Disable button if cart is empty
                >
                  Proceed To Checkout
                </Button>
              </Link>
            ) : (
              <Button
                onClick={() => setIsLoginOpen(true)}
                className="w-full mt-4"
              >
                Proceed To Checkout
              </Button>
            )}
          </Card>
        </div>
      </div>
      <AuthModal isOpen={isLoginOpen} setIsOpen={setIsLoginOpen} />
    </>
  );
}
